@@ -227,7 +227,7 @@ class AboutWindow(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.label = QLabel(self)
-        AboutTxt = "<h3>Gngeo-gui 0.0.5-5</h3><p>" \
+        AboutTxt = "<h3>Gngeo-gui 0.0.5-6</h3><p>" \
                    "<img src=/opt/usr/share/icons/hicolor/64x64/apps/gngeo_gui.png /><br>" \
                    "GnGeo-gui is a Graphical User Interface for GnGeo<p> " \
                    "GnGeo emulates the NeoGeo gameconsole from SNK &#174;</p>" \
@@ -324,11 +324,14 @@ class ConfigWindow(QMainWindow):
 	# system
 	grid.addWidget(QLabel("<center>system:</center>"), 4, 1)
         self.comboSystem = QComboBox(self)
-#	self.comboSystem.setStatusTip('system')
         grid.addWidget(self.comboSystem,5,1)
-	systems = self.listDefaultFirst("system",['arcade','home'])
+	systems = self.listDefaultFirst("system",['arcade','home','unibios'])
 	for sysType in systems:
-       		 	self.comboSystem.addItem(sysType)
+			if sysType == 'unibios':
+				if os.path.exists(self.options["biospath"] + "/uni-bios.rom"):
+       			 		self.comboSystem.addItem('unibios')
+			else:
+	       		 	self.comboSystem.addItem(sysType)
 	# country
 	grid.addWidget(QLabel("<center>region:</center>"), 4, 2)
         self.comboCountry = QComboBox(self)
